##  Prerequisites
To implement pace layering, you need a business capability map. Business capability mapping helps IT and business understand each other's needs and gain transparency in enterprise architecture. It enables organizations to make informed decisions by classifying their capabilities into differentiation, innovation, and commodity.
Read more on defining business capabilities in [Getting Data into Your Workspace](https://help.sap.com/docs/leanix/ea/get-data-into-workspace?locale=en-US&state=PRODUCTION&version=CLOUD "Getting initial data into SAP LeanIX workspace."). You can use [SAP LeanIX’s business capability map template![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fen%2Fdownload%2Fbest-practices-to-define-business-capability-maps "https://www.leanix.net/en/download/best-practices-to-define-business-capability-maps") as a quick start.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27514def7a441014972ec025b421589c_LowRes.png)
YesNo
Send
